pitchtools.chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_flats
================================================================================

.. autofunction:: abjad.tools.pitchtools.chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_flats.chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_flats
